/*
   orxonox - the future of 3D-vertical-scrollers

   Copyright (C) 2004 orx

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

### File Specific:
   main-programmer: Patrick Boenzli
*/

#include "glgui.h"
#include "shell_command.h"

#include "network_stream.h"
#include "debug.h"

#include "network_monitor.h"
#include "network_node.h"


SHELL_COMMAND(showGUI, NetworkMonitor, showGUI);
SHELL_COMMAND(hideGUI, NetworkMonitor, hideGUI);
// SHELL_COMMAND(output, MappedWater, saveParams);



/**
 * starts a network monitor
 */
NetworkMonitor::NetworkMonitor(NetworkStream* networkStream)
{
  this->playerNumber = 0;
}


/**
 * deconstructor
 */
NetworkMonitor::~NetworkMonitor()
{}


/**
 * adds a client
 */
void NetworkMonitor::addClient(PeerInfo* node)
{
  this->clientList.push_back(node);
  this->playerNumber++;
}

/**
 * adds a proxy server
 */
void NetworkMonitor::addProxyServer(PeerInfo* node)
{
  this->proxyServerList.push_back(node);
  this->playerNumber++;
}

/**
 * adds a master server
 */
void NetworkMonitor::addMasterServer(PeerInfo* node)
{
  this->masterServerList.push_back(node);
  this->playerNumber++;
}

/**
 * removes a client
 */
void NetworkMonitor::removeClient(PeerInfo* node)
{
  std::list<PeerInfo*>::iterator it = this->clientList.begin();
  for(; it != this->clientList.end(); it++)
  {
    if( *it == node)
    {
      this->clientList.erase(it);
      this->playerNumber--;
      return;
    }
  }

  PRINTF(2)("Could not remove client from the list, very strange...");
}

/**
 * removes a proxy server
 */
void NetworkMonitor::removeProxyServer(PeerInfo* node)
{
  std::list<PeerInfo*>::iterator it = this->proxyServerList.begin();
  for(; it != this->proxyServerList.end(); it++)
  {
    if( *it == node)
    {
      this->proxyServerList.erase(it);
      this->playerNumber--;
      return;
    }
  }

  PRINTF(2)("Could not remove proxy server from the list, very strange...");
}

/**
 * removes a master server
 */
void NetworkMonitor::removeMasterServer(PeerInfo* node)
{
  std::list<PeerInfo*>::iterator it = this->masterServerList.begin();
  for(; it != this->masterServerList.end(); it++)
  {
    if( *it == node)
    {
      this->masterServerList.erase(it);
      this->playerNumber--;
      return;
    }
  }

  PRINTF(2)("Could not remove client from the list, very strange...");
}



/**
 * this displays the network monitor gui
 */
void NetworkMonitor::showGUI()
{
  if (this->box == NULL)
  {
    this->box = new OrxGui::GLGuiBox(OrxGui::Vertical);
    {
      OrxGui::GLGuiBox* waterColorBox = new OrxGui::GLGuiBox(OrxGui::Horizontal);
      {
        OrxGui::GLGuiText* waterColorText = new OrxGui::GLGuiText();
        waterColorText->setText("NetworkMonitor");
        waterColorBox->pack(waterColorText);
      }
      this->box->pack(waterColorBox);
    }

    this->box->showAll();
    this->box->setAbsCoor2D(300, 40);
    OrxGui::GLGuiHandler::getInstance()->activate();
//     OrxGui::GLGuiHandler::getInstance()->activateCursor();
  }
}


/**
 * hides the network monitor gui again
 */
void NetworkMonitor::hideGUI()
{
  if( this->box == NULL)
    return;

  OrxGui::GLGuiHandler::getInstance()->deactivate();
//   OrxGui::GLGuiHandler::getInstance()->deactivateCursor();

  delete this->box;
  this->box = NULL;
}


/**
 * processes the network monitor data
 */
void NetworkMonitor::process()
{

}

